pub enum CommandScope {
SwitchesToVertical,
SwitchesToHorizontal,
MathOnly,
SwitchesToHorizontalOrMath,
Any,
}Expand description
The scope of a PrimitiveCommand::Unexpandable.
Variants
SwitchesToVertical
The command is only valid in vertical mode. If occuring in horizontal mode, it will close the current paragraph, i.e. switch to vertical mode. In restricted horizontal or math mode, it will throw an error.
SwitchesToHorizontal
The command is only valid in horizontal mode. If occuring in (internal) vertical mode, it will open a new paragraph, i.e. switch to horizontal mode. In math mode, it will throw an error.
MathOnly
The command is only valid in math mode. If occuring in non-math mode, it will throw an error
SwitchesToHorizontalOrMath
The command is only valid in horizontal or math mode. If occuring in vertical mode, it will open a new paragraph, i.e. switch to horizontal mode.
Any
The command is valid anywhere and will not switch modes.