pub enum ResolvedToken<'a, ET: EngineTypes> {
Tk {
char: ET::Char,
code: CommandCode,
},
Cmd(Option<&'a TeXCommand<ET>>),
}Expand description
A Token that has been resolved to a TeXCommand or a character (if not a control sequence / active character).
Variants
Tk
The token is a simple character with the given CommandCode.
Cmd(Option<&'a TeXCommand<ET>>)
The token is a control sequence or active character, which
is currently defined as the give TeXCommand (or undefined).